@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2019 Michal Čihař <michal@cihar.com>
+# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate <https://weblate.org/>
 #
@@ -21,23 +21,25 @@ from django.core.exceptions import ObjectDoesNotExist
 from fedora_messaging.api import Message, publish
 from fedora_messaging.exceptions import ConnectionException, PublishReturned
 from weblate.trans.models import Change
+from weblate.trans.util import split_plural
 from weblate.utils.celery import app
 from weblate.utils.site import get_site_url
 
 
 def get_change_topic(change):
-    scope = "global"
-    if change.unit:
-        scope = "unit"
-    elif change.translation:
-        scope = "translation"
-    elif change.component:
-        scope = "component"
-    elif change.project:
-        scope = "project"
-    return "weblate.{}.{}".format(
-        scope, change.get_action_display().lower().replace(" ", "_")
-    )
+    """
+    Generates a topic for the change.
+
+    Is is in the form weblate.<action>.<project>.<component>.<translation>
+    """
+    parts = ["weblate", change.get_action_display().lower().replace(" ", "_")]
+    if change.project:
+        parts.append(change.project.slug)
+    if change.component:
+        parts.append(change.component.slug)
+    if change.translation:
+        parts.append(change.translation.language.code)
+    return ".".join(parts)
 
 
 def get_change_body(change):
@@ -50,9 +52,9 @@ def get_change_body(change):
     if url:
         result["url"] = get_site_url(url)
     if change.target:
-        result["target"] = change.target
+        result["target"] = split_plural(change.target)
     if change.old:
-        result["old"] = change.old
+        result["old"] = split_plural(change.old)
     if change.author:
         result["author"] = change.author.username
     if change.user:
@@ -64,11 +66,23 @@ def get_change_body(change):
     if change.translation:
         result["translation"] = change.translation.language.code
     if change.unit:
-        result["source"] = change.unit.source
+        result["source"] = split_plural(change.unit.source)
+        result["context"] = change.unit.context
     result.update(change.details)
     return result
 
 
+def get_change_headers(change):
+    result = {
+        "action": change.get_action_display(),
+    }
+    if change.project:
+        result["project"] = change.project.slug
+    if change.component:
+        result["component"] = change.component.slug
+    return result
+
+
 # Retry for not existing object (maybe transaction not yet committed) with
 # delay of 10 minutes growing exponentially
 @app.task(
@@ -79,4 +93,10 @@ def get_change_body(change):
 )
 def fedora_messaging_change(change_id):
     change = Change.objects.get(pk=change_id)
-    publish(Message(topic=get_change_topic(change), body=get_change_body(change)))
+    publish(
+        Message(
+            topic=get_change_topic(change),
+            headers=get_change_headers(change),
+            body=get_change_body(change),
+        )
+    )
