@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2019 Michal Čihař <michal@cihar.com>
+# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate <https://weblate.org/>
 #
@@ -48,4 +48,14 @@ class FedoraTestCase(FixtureTestCase):
             user=user,
             author=User.objects.get(username="jane"),
         )
+
+    @modify_settings(INSTALLED_APPS={"append": "weblate_fedora_messaging"})
+    def test_edit(self):
         self.edit_unit("Hello, world!\n", "Ahoj svete!\n")
+
+    @modify_settings(INSTALLED_APPS={"append": "weblate_fedora_messaging"})
+    def test_plural(self):
+        self.edit_unit(
+            "Orangutan has %d banana.\n\u001e\u001eOrangutan has %d bananas.\n",
+            "Opice má %d banán.\n",
+        )
